@@ -14,7 +14,6 @@ from django.forms.util import ErrorList
 from django.http import Http404, HttpResponseRedirect
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
-from django.views.decorators.http import condition
 
 import mptt
 
@@ -338,6 +337,10 @@ class Page(Base):
             etag = page.etag(request)
             return etag
 
+        # Unavailable in Django 1.0 -- the current implementation of ETag support
+        # requires Django 1.1 unfortunately.
+        from django.views.decorators.http import condition
+
         # Now wrap the condition decorator around our dummy handler:
         # the net effect is that we will be getting a DummyResponse from
         # the handler if processing is to continue and a non-DummyResponse
@@ -359,8 +362,12 @@ class Page(Base):
         if etag is not None:
             response['ETag'] = etag
 
-    def debug_sql_queries_response_processor(self, request, response):
-        if django_settings.DEBUG:
+    @staticmethod
+    def debug_sql_queries_response_processor(verbose=False):
+        if not django_settings.DEBUG:
+            return lambda self, request, response: None
+
+        def processor(self, request, response):
             from django.db import connection
 
             print_sql = lambda x: x
@@ -370,18 +377,21 @@ class Page(Base):
             except:
                 pass
 
-            print "--------------------------------------------------------------"
+            if verbose:
+                print "--------------------------------------------------------------"
             time = 0.0
             i = 0
             for q in connection.queries:
                 i += 1
-                print "%d : [%s]\n%s\n" % ( i, q['time'], print_sql(q['sql']))
+                if verbose:
+                    print "%d : [%s]\n%s\n" % ( i, q['time'], print_sql(q['sql']))
                 time += float(q['time'])
 
             print "--------------------------------------------------------------"
             print "Total: %d queries, %f ms" % (i, time)
             print "--------------------------------------------------------------"
 
+        return processor
 
     @classmethod
     def register_request_processors(cls, *processors):
@@ -400,7 +410,11 @@ class Page(Base):
             if ext in cls._feincms_extensions:
                 continue
 
-            fn = get_object('feincms.module.page.extensions.%s.register' % ext)
+            try:
+                fn = get_object(ext + '.register')
+            except ImportError:
+                fn = get_object('feincms.module.page.extensions.%s.register' % ext)
+
             fn(cls, PageAdmin)
             cls._feincms_extensions.add(ext)
 
@@ -529,23 +543,23 @@ class PageAdmin(editor.ItemEditor, list_modeladmin):
 
     # the fieldsets config here is used for the add_view, it has no effect
     # for the change_view which is completely customized anyway
-    fieldsets = (
+    fieldsets = [
         (None, {
-            'fields': ('active', 'in_navigation', 'template_key', 'title', 'slug',
-                'parent'),
+            'fields': ['active', 'in_navigation', 'template_key', 'title', 'slug',
+                'parent'],
         }),
         (_('Other options'), {
-            'classes': ('collapse',),
-            'fields': ('override_url',),
+            'classes': ['collapse',],
+            'fields': ['override_url',],
         }),
-        )
+        ]
     list_display = ['short_title', 'is_visible_admin', 'in_navigation_toggle', 'template']
-    list_filter = ('active', 'in_navigation', 'template_key', 'parent')
-    search_fields = ('title', 'slug')
+    list_filter = ['active', 'in_navigation', 'template_key', 'parent']
+    search_fields = ['title', 'slug']
     prepopulated_fields = { 'slug': ('title',), }
 
     raw_id_fields = []
-    show_on_top = ('title', 'active')
+    show_on_top = ['title', 'active']
     radio_fields = {'template_key': admin.HORIZONTAL}
 
     in_navigation_toggle = editor.ajax_editable_boolean('in_navigation', _('in navigation'))
